This function is exported because it needs to be called in the main plumber endpoint function.
See also
Other pkgmatch:
pkgmatch_repo(),
ros_to_list()
This function is exported because it needs to be called in the main plumber endpoint function.
Other pkgmatch:
pkgmatch_repo(),
ros_to_list()