Determine whether a GitHub issue is a Stats submission
Usage
issue_is_stats(orgrepo, issue_num)
Arguments
- orgrepo
GitHub organization and repo as single string separated by
forward slash (org/repo).
- issue_num
Number of issue from which to extract submission type.
Value
TRUE if the submission type is "Stats", otherwise FALSE.