List all volunteer searches with recipient and click counts
Source:R/editor-search.R
list_searches.RdList all volunteer searches with recipient and click counts
See also
Other email:
deactivate_search(),
deactivate_stale_searches(),
handle_click(),
send_search()