R/dependencies.R
pkgrep_install_deps.RdInstall all system and package dependencies of an R package
pkgrep_install_deps(path, os, os_release)
| path | Path to local package |
|---|---|
| os | Name of operating system, passed to remotes package to install system dependencies. |
| os_release | Name of operating system release, passed to remotes package to install system dependencies. |
Hopefully a character vector of length zero, otherwise a list of any R packages unable to be installed.
Other utils:
check_cache(),
stdout_stderr_cache(),
symbol_crs(),
symbol_tck()