This function is exported because it needs to be called in the main plumber endpoint function.
See also
Other pkgmatch:
cran_to_list(),
pkgmatch_repo()
This function is exported because it needs to be called in the main plumber endpoint function.
Other pkgmatch:
cran_to_list(),
pkgmatch_repo()