Auto-deactivate and delete stale volunteer searches
Source:R/editor-search.R
deactivate_stale_searches.RdSearches are never automatically closed otherwise, so this is intended to
be called periodically (see serve_api()) to stop searches that are
never explicitly deactivated from accumulating in the database forever.
Any search whose created_at is older than max_age_days is
deactivated and has all its data removed, exactly as deactivate_search()
does for a single search.
See also
Other email:
deactivate_search(),
handle_click(),
list_searches(),
send_search()